@@ -53,11 +53,14 @@ class WandbLogger(LightningLoggerBase):
         project: The name of the project to which this run will belong.
         log_model: Save checkpoints in wandb dir to upload on W&B servers.
         experiment: WandB experiment object.
+        prefix: A string to put at the beginning of metric keys.
         \**kwargs: Additional arguments like `entity`, `group`, `tags`, etc. used by
             :func:`wandb.init` can be passed as keyword arguments in this logger.
 
     Example::
 
+    .. code::
+
         from pytorch_lightning.loggers import WandbLogger
         from pytorch_lightning import Trainer
         wandb_logger = WandbLogger()
@@ -70,6 +73,8 @@ class WandbLogger(LightningLoggerBase):
 
     """
 
+    LOGGER_JOIN_CHAR = '-'
+
     def __init__(
         self,
         name: Optional[str] = None,
@@ -81,6 +86,7 @@ class WandbLogger(LightningLoggerBase):
         project: Optional[str] = None,
         log_model: bool = False,
         experiment=None,
+        prefix: str = '',
         **kwargs
     ):
         if wandb is None:
@@ -95,6 +101,7 @@ class WandbLogger(LightningLoggerBase):
         self._experiment = experiment
         self._offline = offline
         self._log_model = log_model
+        self._prefix = prefix
         self._kwargs = kwargs
         # logging multiple Trainer on a single W&B run (k-fold, etc)
         self._step_offset = 0
@@ -126,7 +133,7 @@ class WandbLogger(LightningLoggerBase):
                 os.environ['WANDB_MODE'] = 'dryrun'
             self._experiment = wandb.init(
                 name=self._name, dir=self._save_dir, project=self._project, anonymous=self._anonymous,
-                reinit=True, id=self._id, resume='allow', **self._kwargs)
+                id=self._id, resume='allow', **self._kwargs) if wandb.run is None else wandb.run
             # save checkpoints in wandb dir to upload on W&B servers
             if self._log_model:
                 self._save_dir = self._experiment.dir
@@ -145,6 +152,8 @@ class WandbLogger(LightningLoggerBase):
     @rank_zero_only
     def log_metrics(self, metrics: Dict[str, float], step: Optional[int] = None) -> None:
         assert rank_zero_only.rank == 0, 'experiment tried to log from global_rank != 0'
+
+        metrics = self._add_prefix(metrics)
         self.experiment.log(metrics, step=(step + self._step_offset) if step is not None else None)
 
     @property
@@ -161,6 +170,7 @@ class WandbLogger(LightningLoggerBase):
         # don't create an experiment if we don't have one
         return self._experiment.id if self._experiment else self._id
 
+    @rank_zero_only
     def finalize(self, status: str) -> None:
         # offset future training logged on same W&B run
         if self._experiment is not None:
